Vue.filter('moment', function (date, format, convert) {
	return convert !== false ? moment(date * 1000).utc().format(format) : moment(date * 1000).format(format);
});


if(typeof SimpleWeather.locale !== 'undefined' ){
	moment.updateLocale('en', SimpleWeather.locale);
}

var simple_weather_apps = [];

Array.prototype.forEach.call( document.querySelectorAll('div.simple-weather--vue'), function(el, index){

  var id = el.getAttribute('id').replace( 'simple-weather--', '' );

  simple_weather_apps[index] = new Vue({
    el: '#simple-weather--' + id,
    mounted: function() {
      var vm = this;
      var classes = [ 'simple-weather--vue-mounted' ];

      if( typeof vm.atts.text_align !== 'undefined' && vm.atts.text_align !== null && vm.atts.text_align.length > 0 ){
        classes.push( 'simple-weather--text-' + vm.atts.text_align );
      }

      if( typeof vm.atts.style !== 'undefined' && vm.atts.style !== null && vm.atts.style.length > 0 ){
        classes.push( 'simple-weather--view-' + vm.atts.style );
      }

      if( typeof vm.display !== 'undefined' &&  vm.atts.display === 'block' ){
        classes.push( 'simple-weather--display-block' );
      }

      if( typeof vm.show_date !== 'undefined' && ! vm.filter_var( vm.atts.show_date ) ){
        classes.push( 'simple-weather--hidden-date' );
      }

      vm.$el.className += ' ' + classes.join( ' ' );

      if( Object.keys(vm.feed).length === 0 && vm.feed.constructor === Object ){
        vm.get_weather();
      }
    },
    data: function(){

			var vm = this;
			var atts = typeof window['SimpleWeatherAtts'] !== 'undefined' && typeof window['SimpleWeatherAtts'][id] !== 'undefined' ? window['SimpleWeatherAtts'][id] : {};
			var feed = {};
			var feed_current_weather = {};

			if( typeof atts.station !== 'undefined' && atts.station === 'darksky' ){
				if( typeof window['SimpleWeatherFeeds'] !== 'undefined' && typeof window['SimpleWeatherFeeds'][id] !== 'undefined' && typeof window['SimpleWeatherFeeds'][id].forecast !== 'undefined' ){
					feed = window['SimpleWeatherFeeds'][id].forecast.daily;
					feed_current_weather = typeof window['SimpleWeatherFeeds'][id].forecast.currently !== 'undefined' ? window['SimpleWeatherFeeds'][id].forecast.currently : {};
				}
			} else {
				if( typeof window['SimpleWeatherFeeds'] !== 'undefined' && typeof window['SimpleWeatherFeeds'][id] !== 'undefined' ){
					feed = window['SimpleWeatherFeeds'][id].forecast;
					feed_current_weather = typeof window['SimpleWeatherFeeds'][id].current !== 'undefined' ? window['SimpleWeatherFeeds'][id].current : {};
				}
			}

      return {
        atts: atts,
        feed: feed,
        feed_current_weather: feed_current_weather,
				visible: []
      }
    },
    filters: {
      temp: function(temp){
        return typeof temp !== 'undefined' ? parseInt( temp ) : '';
      }
    },
    computed: {
      units: function(){
        return typeof this.atts.units !== 'undefined' && this.atts.units === 'imperial' ? 'F' : 'C';
      },
			units_wind: function(){
				return typeof this.atts.units !== 'undefined' && this.atts.units === 'imperial' ? 'mph' : 'kph';
			},
      current_weather: function(){
        var vm = this;
        var out = {};

        if( vm.weather_station === 'openweather' ){
          if(typeof vm.feed_current_weather.weather !== 'undefined' && typeof vm.feed_current_weather.weather[0].id !== 'undefined' ){
						out.id = vm.feed_current_weather.weather[0].id;
						out.desc = vm.feed_current_weather.weather[0].description;
					}
          if(typeof vm.feed_current_weather.dt !== 'undefined' ) out.dt = vm.feed_current_weather.dt;
          if(typeof vm.feed_current_weather.main !== 'undefined' && typeof vm.feed_current_weather.main.temp !== 'undefined' ){
						out.temp = vm.feed_current_weather.main.temp;
						out.humidity = Math.ceil( vm.feed_current_weather.main.humidity );
					}
					if(typeof vm.feed_current_weather.clouds !== 'undefined' ) out.clouds = Math.ceil( vm.feed_current_weather.clouds.all );
					if(typeof vm.feed_current_weather.wind !== 'undefined' ) {
						out.wind = {};
						out.wind.deg = vm.getWindDirection( vm.feed_current_weather.wind.deg );
						out.wind.speed = vm.units === 'metric' ? vm.feed_current_weather.wind.speed * 3.6 : vm.feed_current_weather.wind.speed * 3.6 / 1.609344;
						out.wind.speed = Math.ceil(out.wind.speed);
					}
					if(typeof vm.feed_current_weather.name !== 'undefined' ) out.name = vm.feed_current_weather.name;
				}

				if( vm.weather_station === 'darksky' ){
					if(typeof vm.feed_current_weather.icon !== 'undefined' ) out.id = vm.feed_current_weather.icon;
					if(typeof vm.feed_current_weather.summary !== 'undefined' ) out.desc = vm.feed_current_weather.summary;
					if(typeof vm.feed_current_weather.humidity !== 'undefined' ) out.humidity = Math.ceil( vm.feed_current_weather.humidity * 100 );
					if(typeof vm.feed_current_weather.cloudCover !== 'undefined' ) out.clouds = Math.ceil( vm.feed_current_weather.cloudCover * 100 );
					out.wind = {};
					if(typeof vm.feed_current_weather.windBearing !== 'undefined' ) out.wind.deg = vm.getWindDirection( vm.feed_current_weather.windBearing );
					if(typeof vm.feed_current_weather.windSpeed !== 'undefined' ) out.dt = vm.feed_current_weather.windSpeed;
          if(typeof vm.feed_current_weather.time !== 'undefined' ) out.dt = vm.feed_current_weather.time;
          if(typeof vm.feed_current_weather.temperature !== 'undefined' ) out.temp = vm.feed_current_weather.temperature;
				}
        return out;
      },
      weather_feed: function(){
        var vm = this;
				var out = [];

				if( vm.weather_station === 'openweather' ){
					if( typeof vm.feed.list !== 'undefined' ){
						vm.feed.list.forEach(function(val, index){
							out.push({
								dt: val.dt,
								id: val.weather[0].id,
								temp: val.temp.day,
								temp_min: val.temp.night
							});
						});
					}
				}

				if( vm.weather_station === 'darksky' ){
					if( typeof vm.feed.data !== 'undefined' ){
						vm.feed.data.forEach(function(val, index){
							var $push = {
								dt: val.time,
								id: val.icon,
								temp: val.apparentTemperatureMax,
								temp_min: val.apparentTemperatureMin
							};
							if( moment().utc().startOf('day').isBefore( val.time * 1000 ) ) out.push($push);
						});
					}
				}
        return out.length > 0 ? out : false;
      },
      weather_station : function(){
        var vm = this;
        return typeof vm.atts.station !== 'undefined' && vm.atts.station === 'darksky' ? 'darksky' : 'openweather';
      },
			style: function(){
				var vm = this;
				if( typeof vm.atts.style === 'undefined' ) return 'inline';
				return vm.atts.style;
			}
    },
    methods: {
			getWindDirection: function($deg){
				if ($deg >= 0 && $deg < 22.5) return 'N';
				else if ($deg >= 22.5 && $deg < 45) return 'NNE';
				else if ($deg >= 45 && $deg < 67.5) return 'NE';
				else if ($deg >= 67.5 && $deg < 90) return 'ENE';
				else if ($deg >= 90 && $deg < 122.5) return 'E';
				else if ($deg >= 112.5 && $deg < 135) return 'ESE';
				else if ($deg >= 135 && $deg < 157.5) return 'SE';
				else if ($deg >= 157.5 && $deg < 180) return 'SSE';
				else if ($deg >= 180 && $deg < 202.5) return 'S';
				else if ($deg >= 202.5 && $deg < 225) return 'SSW';
				else if ($deg >= 225 && $deg < 247.5) return 'SW';
				else if ($deg >= 247.5 && $deg < 270) return 'WSW';
				else if ($deg >= 270 && $deg < 292.5) return 'W';
				else if ($deg >= 292.5 && $deg < 315) return 'WNW';
				else if ($deg >= 315 && $deg < 337.5) return 'NW';
				else if ($deg >= 337.5 && $deg < 360) return 'NNW';
				else return;
			},
			getWeatherIcon: function( day ){
				return this.weather_station === 'darksky' ? 'sw-forecast-io-' + day.id : 'sw-owm-' + day.id;
			},
			isset: function( $key ){
				return typeof vm.atts[$key] !== 'undefined' &&  vm.atts[$key] !== null &&  vm.atts[$key].length > 0;
			},
      hasCurrentWeather: function(){
        var vm = this;
        return vm.filter_var( vm.atts.show_current );
      },
      isDayVisible: function(index, day){
        var vm = this;
				var out = false;
				var days = parseInt( vm.atts.days );

        if( vm.filter_var( vm.atts.show_current ) ){
					return index > 0 && index <= days;
        } else {
					return index < days;
        }

      },
      filter_var: function( test ){
        return [1, true, 'on', 'true', '1', 'yes'].indexOf(test) >= 0 ? true : false;
      },
      get_weather: function(){
        var vm = this;
        vm.$http.get(
					window.SimpleWeather.rest_route + 'simple-weather/v1/get_weather/',
          {
            params: vm.atts
          }
        ).then(vm.successCallback, vm.errorCallback);
      },
      successCallback: function(response){
        var vm = this;
        if( vm.weather_station === 'openweather' ){
          if( response.status >= 200 && response.status <= 202 ){
            vm.feed = response.body.forecast;
						if( typeof response.body.current !== 'undefined' ){
              vm.feed_current_weather = response.body.current;
            }
						if( typeof response.body.current !== 'undefined' ){
              vm.feed_current_weather = response.body.current;
            }
          }
        }

				if( vm.weather_station === 'darksky' ){
					if( response.status >= 200 && response.status <= 202 ){
            vm.feed = response.body.forecast.daily;
            if( typeof response.body.forecast.currently !== 'undefined' ){
              vm.feed_current_weather = response.body.forecast.currently;
            }
          }
				}

      },
      errorCallback: function(response){
				console.log(response);
      }
    }
  });

});
