<?php
/*
Plugin Name: Simple Weather
Plugin URI: https://demo.curlythemes.com/weather/
Description: This plugin gives you a simple shortcode & widget to display the weather.
Version: 4.0.3
Author: پرشین اسکریپت
Author URI: http://www.persianscript.ir/
*/

define( 'SIMPLER_WEATHER_FILE', __FILE__ );
define( 'SIMPLER_WEATHER_PATH', untrailingslashit( plugin_dir_path( SIMPLER_WEATHER_FILE ) ) );

// Create a helper function for easy SDK access.
function sw_fs() {
    global $sw_fs;

    if ( ! isset( $sw_fs ) ) {
        // Include Freemius SDK.
        require_once dirname(__FILE__) . '/freemius/start.php';

        $sw_fs = fs_dynamic_init( array(
            'id'                  => '1409',
            'slug'                => 'simple-weather',
            'type'                => 'plugin',
            'public_key'          => 'pk_77bef369a213c0f336c8d28c40ff4',
            'is_premium'          => false,
            'has_addons'          => false,
            'has_paid_plans'      => false,
            'is_org_compliant'    => false,
            'menu'                => array(
                'slug'           => 'simple-weather',
                'account'        => false,
                'contact'        => false,
                'support'        => false,
                'parent'         => array(
                    'slug' => 'options-general.php',
                ),
            ),
        ) );
    }

    return $sw_fs;
}

// Init Freemius.
sw_fs();
// Signal that SDK was initiated.
do_action( 'sw_fs_loaded' );

function sw_fs_custom_connect_message_on_update(
  $message,
  $user_first_name,
  $plugin_title,
  $user_login,
  $site_link,
  $freemius_link
) {
  return sprintf(
      __fs( 'hey-x' ) . '<br>' .
      __( 'Never miss an important update for %2$s! <br> Opt-in to our security and feature updates notifications, and non-sensitive diagnostic tracking.', 'simple-weather' ),
      $user_first_name,
      '<b>' . $plugin_title . '</b>',
      '<b>' . $user_login . '</b>',
      $site_link,
      $freemius_link
  );
}
sw_fs()->add_filter('connect_message', 'sw_fs_custom_connect_message_on_update', 10, 6);
sw_fs()->add_filter('connect_message_on_update', 'sw_fs_custom_connect_message_on_update', 10, 6);



require_once('class.wp.rest.api.php');

function simple_weather_get_template_part( $slug, $name = '' ) {

    $template = '';

    if ( $name ) {
        $template = locate_template( array( "{$slug}-{$name}.php", apply_filters( 'simple_weather_template_path', 'simple_weather_templates/' ) . "{$slug}-{$name}.php" ) );
    }

    if ( ! $template && $name && file_exists( SIMPLER_WEATHER_PATH . "/templates/{$slug}-{$name}.php" ) ) {
        $template = SIMPLER_WEATHER_PATH . "/templates/{$slug}-{$name}.php";
    }

    if ( ! $template ) {
        $template = locate_template( array( "{$slug}.php", apply_filters( 'simple_weather_template_path', 'simple_weather_templates/' ) . "{$slug}.php" ) );
    }

    if ( ! $template && file_exists( SIMPLER_WEATHER_PATH . "/templates/{$slug}.php" ) ) {
	    $template = SIMPLER_WEATHER_PATH . "/templates/{$slug}.php";
    }

    $template = apply_filters( 'simple_weather_get_template_part', $template, $slug, $name );

    if ( $template ) {
        return $template;
    }
}


if( ! class_exists( 'CurlySimpleWeather' ) ){

	/**
	* Simple Weather
	*/
	class CurlySimpleWeather {

		/** Constructor */
		function __construct(){

			/** Load Scripts */
			add_action( 'wp_enqueue_scripts', array( $this, 'load_scripts') );

			/** Textdomain */
			add_action( 'plugins_loaded', array( $this, 'set_textdomain' ) );

			/** Load Widget */
			require_once('simple-weather-widget.php');

			/** Weather Shortcode */
			add_shortcode( 'simple-weather', array( $this, 'weather_shortcode' ) );
			add_action( 'wp_footer', array($this, 'footer') );

      add_action( 'admin_menu', array( $this, 'register_options_page' ) );

      /** Load Scripts */
			add_action( 'admin_enqueue_scripts', array( $this, 'load_admin_scripts') );

      add_filter( 'simple-weather-options', array( $this, 'default_options' ) );

		}

    function default_options(){
      return array(
        'lang_ow' => 'en',
        'lang_ds' => 'en',
        'units' => 'imperial',
        'api_ow' => '',
        'api_ds' => '',
        'async' => true,
        'freq' => 0,
        'timeout' => 30,
        'station' => 'openweather'
      );
    }

    function load_admin_scripts(){

      wp_enqueue_style( 'simple-weather-element', 'https://unpkg.com/element-ui/lib/theme-default/index.css' );
      wp_enqueue_style( 'simple-weather-admin', plugins_url( '/css/simple-weather-admin.css' , __FILE__ ), array( 'simple-weather-element' ), rand() );

      wp_enqueue_script( 'simple-weather-vue', 'https://cdnjs.cloudflare.com/ajax/libs/vue/2.4.4/vue.js', array( 'jquery' ), null, true );
      wp_enqueue_script( 'simple-weather-vue-resource', 'https://cdnjs.cloudflare.com/ajax/libs/vue-resource/1.3.4/vue-resource.js', array( 'simple-weather-vue' ), null, true );
      wp_enqueue_script( 'simple-weather-moment', 'https://cdnjs.cloudflare.com/ajax/libs/moment.js/2.18.1/moment.min.js', array( 'simple-weather-vue' ), null, true );
      wp_enqueue_script( 'simple-weather-element', 'https://unpkg.com/element-ui/lib/index.js', array( 'simple-weather-vue' ), null, true );
      wp_enqueue_script( 'simple-weather-admin', plugins_url( '/js/simple-weather-admin-min.js' , __FILE__ ), array( 'jquery', 'simple-weather-vue', 'simple-weather-vue-resource', 'simple-weather-moment', 'simple-weather-element' ), rand(), true );

      wp_localize_script( 'simple-weather-admin', 'SimpleWeather', array( 'rest_route' => esc_url_raw( get_rest_url() ), 'nonce' => wp_create_nonce( 'wp_rest' ) ) );

    }

    function options_page(){
      ?>
      <div id="app" class="wrap" v-cloak>
        <h1>Simple Weather Settings</h1>
        <el-form v-if="form" ref="form" :model="form"  label-width="220px" class="simple-weather-settings-form" v-loading="loading">

          <el-tabs v-model="tabs">
            <el-tab-pane label="General" name="general">

              <el-form-item label="Lazy Load Weather">
                <el-switch
                  v-model="form.async"
                  on-text="Yes"
                  off-text="No">
                </el-switch>
                <small>Enabling this option, your website will load faster and loading the weather will bypass static page caching.</small>
              </el-form-item>

              <el-form-item label="Default Weather Station">
                <el-radio-group v-model="form.station">
                  <el-radio label="openweather">OpenWeatherMap.org</el-radio>
                  <el-radio label="darksky">DarkSky.net</el-radio>
                </el-radio-group>
              </el-form-item>

              <el-form-item label="Default Measuring Units">
                <el-radio-group v-model="form.units">
                  <el-radio label="imperial">Imperial (&deg;F)</el-radio>
                  <el-radio label="metric">Metric (&deg;C)</el-radio>
                </el-radio-group>
              </el-form-item>

            </el-tab-pane>
            <el-tab-pane label="OpenWeather" name="ow">

              <el-form-item label="OpenWeather API Key">
                <el-input v-model="form.api_ow" placeholder="Enter your OpenWeather API here"></el-input>
                <small>You can improve the overall performance of our plugin, if you use your own API Key from <a href="https://home.openweathermap.org/users/sign_up" target="_blank">OpenWeatherMap.org</a></small>
              </el-form-item>

              <el-form-item label="OpenWeather Language">
                <el-select v-model="form.lang_ow" filterable placeholder="Select Language">
                  <el-option label="Arabic" value="ar"></el-option>
                  <el-option label="Bulgarian" value="bg"></el-option>
                  <el-option label="Catalan" value="ca"></el-option>
                  <el-option label="Czech" value="cz"></el-option>
                  <el-option label="English" value="en"></el-option>
                  <el-option label="German" value="de"></el-option>
                  <el-option label="Greek" value="el"></el-option>
                  <el-option label="Persian (Farsi)" value="fa"></el-option>
                  <el-option label="Finnish" value="fi"></el-option>
                  <el-option label="French" value="fr"></el-option>
                  <el-option label="Galician" value="gl"></el-option>
                  <el-option label="Croatian" value="hr"></el-option>
                  <el-option label="Hungarian" value="hu"></el-option>
                  <el-option label="Italian" value="it"></el-option>
                  <el-option label="Japanese" value="ja"></el-option>
                  <el-option label="Korean" value="kr"></el-option>
                  <el-option label="Latvian" value="la"></el-option>
                  <el-option label="Lithuanian" value="lt"></el-option>
                  <el-option label="Macedonian" value="mk"></el-option>
                  <el-option label="Dutch" value="nl"></el-option>
                  <el-option label="Polish" value="pl"></el-option>
                  <el-option label="Portuguese" value="pt"></el-option>
                  <el-option label="Romanian" value="ro"></el-option>
                  <el-option label="Russian" value="ru"></el-option>
                  <el-option label="Swedish" value="se"></el-option>
                  <el-option label="Slovak" value="sk"></el-option>
                  <el-option label="Slovenian" value="sl"></el-option>
                  <el-option label="Spanish" value="es"></el-option>
                  <el-option label="Turkish" value="tr"></el-option>
                  <el-option label="Ukrainian" value="ua"></el-option>
                  <el-option label="Vietnamese" value="vi"></el-option>
                  <el-option label="Chinese Simplified" value="zh_cn"></el-option>
                  <el-option label="Chinese Traditional" value="zh_tw"></el-option>
                </el-select>
              </el-form-item>

            </el-tab-pane>
            <el-tab-pane label="Dark Sky" name="ds">

              <el-form-item label="DarkSky API Key">
                <el-input v-model="form.api_ds"  placeholder="Enter your DarkSky API here"></el-input>
                <small>You can use the DarkSky API, but you need to use your own API Key which you can generate from <a href="https://darksky.net/dev/register" target="_blank">DarkSky.net</a></small>
              </el-form-item>

              <el-form-item label="DarkSky Language">
                <el-select v-model="form.lang_ds" filterable placeholder="Select Language">
                  <el-option label="Arabic" value="ar"></el-option>
                  <el-option label="Azerbaijani" value="az"></el-option>
                  <el-option label="Belarusian" value="be"></el-option>
                  <el-option label="Bulgarian" value="bg"></el-option>
                  <el-option label="Bosnian" value="bs"></el-option>
                  <el-option label="Catalan" value="ca"></el-option>
                  <el-option label="Czech" value="cz"></el-option>
                  <el-option label="German" value="de"></el-option>
                  <el-option label="Greek" value="el"></el-option>
                  <el-option label="English" value="en"></el-option>
                  <el-option label="Spanish" value="es"></el-option>
                  <el-option label="Estonian" value="et"></el-option>
                  <el-option label="French" value="fr"></el-option>
                  <el-option label="Croatian" value="hr"></el-option>
                  <el-option label="Hungarian" value="hu"></el-option>
                  <el-option label="Indonesian" value="id"></el-option>
                  <el-option label="Italian" value="it"></el-option>
                  <el-option label="Icelandic" value="is"></el-option>
                  <el-option label="Cornish" value="kw"></el-option>
                  <el-option label="Norwegian Bokmål" value="nb"></el-option>
                  <el-option label="Dutch" value="nl"></el-option>
                  <el-option label="Polish" value="pl"></el-option>
                  <el-option label="Portuguese" value="pt"></el-option>
                  <el-option label="Russian" value="ru"></el-option>
                  <el-option label="Slovak" value="sk"></el-option>
                  <el-option label="Slovenian" value="sl"></el-option>
                  <el-option label="Serbian" value="sr"></el-option>
                  <el-option label="Swedish" value="sv"></el-option>
                  <el-option label="Tetum" value="tet"></el-option>
                  <el-option label="Turkish" value="tr"></el-option>
                  <el-option label="Ukrainian" value="ua"></el-option>
                  <el-option label="Igpay Atinlay" value="x-pig-latin"></el-option>
                  <el-option label="Chinese Simplified" value="zh"></el-option>
                  <el-option label="Chinese Traditional" value="zh-tw"></el-option>
                </el-select>
              </el-form-item>

            </el-tab-pane>
            <el-tab-pane label="Advanced" name="advanced">
              <el-form-item label="Default Weather Check Interval (minutes)">
                <el-slider
                  v-model="form.freq"
                  :step="1" show-input :min="0" :max="120">
                </el-slider>
              </el-form-item>

              <el-form-item label="Default API Request Timeout (seconds)">
                <el-slider
                  v-model="form.timeout"
                  :step="1" show-input :min="0" :max="60">
                </el-slider>
              </el-form-item>
            </el-tab-pane>
          </el-tabs>

          <el-form-item>
            <el-button type="primary" @click="onSubmit">Save Settings</el-button>
          </el-form-item>

        </el-form>



      </div>
      <?php
    }

    function register_options_page() {
      add_options_page('Simple Weather Settings', 'Simple Weather', 'manage_options', 'simple-weather', array( $this, 'options_page' ) );
    }


		public static function get_weather_file_new( $atts ){

      $return = array();

      $options = get_option( 'simple-weather-options', apply_filters( 'simple-weather-options', array() ) );

			$atts['station'] = ! isset( $atts['station'] ) || empty( $atts['station'] ) ? $options['station'] : $atts['station'];
			$atts['station'] = $atts['station'] === 'darksky' ? $atts['station'] : $options['station'];

      $atts['api'] = isset( $atts['api'] ) && ! empty( $atts['api'] ) ? esc_attr( $atts['api'] ) : '';
      $atts['lang'] = isset( $atts['lang'] ) && ! empty( $atts['lang'] ) ? esc_attr( $atts['lang'] ) : '';

      if( $atts['station'] === 'openweather' ){
        $atts['api'] = empty( $atts['api'] ) && isset( $options['api_ow'] ) && ! empty( $options['api_ow'] ) ? esc_attr( $options['api_ow'] ) : $atts['api'];
        $atts['lang'] = empty( $atts['lang'] ) && isset( $options['lang_ow'] ) && ! empty( $options['lang_ow'] ) ? esc_attr( $options['lang_ow'] ) : 'en';
      }

      elseif( $atts['station'] === 'darksky' ){
        $atts['api'] = empty( $atts['api'] ) && isset( $options['api_ds'] ) && ! empty( $options['api_ds'] ) ? esc_attr( $options['api_ds'] ) : $atts['api'];
        $atts['lang'] = empty( $atts['lang'] ) && isset( $options['lang_ds'] ) && ! empty( $options['lang_ds'] ) ? esc_attr( $options['lang_ds'] ) : 'en';
      }

      $atts['units'] = isset( $atts['units'] ) && ! empty( $atts['units'] ) ? esc_attr( $atts['units'] ) : esc_attr( $options['units'] );
      $atts['freq'] = isset( $atts['freq'] ) && ! empty( $atts['freq'] ) ? intval( $atts['freq'] ) : intval( $options['freq'] );
      $atts['timeout'] = isset( $atts['timeout'] ) && ! empty( $atts['timeout'] ) ? intval( $atts['timeout'] ) : intval( $options['timeout'] );


      /* Get Weather from DarSky */
			if( $atts['station'] === 'darksky' ){

        if( empty( $atts['api'] ) || ! $atts['api'] ) return new WP_Error( 'no_api', esc_html__('DarkSky need an API key.', 'simple-weather'), array( 'status' => 401 ) );

        if( isset( $atts['latitude'] ) && ! empty( $atts['latitude'] ) && isset( $atts['longitude'] ) && ! empty( $atts['longitude'] ) ){
          $atts['latitude'] = esc_attr( $atts['latitude'] );
          $atts['longitude'] = esc_attr( $atts['longitude'] );
				} else {
          return new WP_Error( 'could_not_get_location', esc_html__('DarkSky needs latitude & longitude coordinates, in order to show the weather.', 'sd'), array( 'status' => 404 ) );
        }

        $darksky_route = "https://api.darksky.net/forecast/{$atts['api']}/{$atts['latitude']},{$atts['longitude']}";

        $query_args = array(
          'lang'  => $atts['lang'],
          'units' => $atts['units'] === 'metric' ? 'si' : 'us',
          'api'		=> $atts['api'],
        );

  			$darksky_route = add_query_arg( $query_args, $darksky_route );

  			$hash = md5( $darksky_route );

  			$transient = get_transient( "sw_data_$hash" );

  			if( ! $transient ){

  				$result = wp_remote_get( esc_url_raw( $darksky_route ), array( 'timeout' => intval( $atts['timeout'] ) ) );

  				if ( ! is_wp_error( $result ) && isset( $result['response']['code'] ) && $result['response']['code'] === 200 ){

  					$transient = json_decode( wp_remote_retrieve_body( $result ) );

  					if( intval( $atts['freq'] ) > 0 )
  						set_transient( "sw_data_$hash", $transient, intval( $atts['freq'] ) * MINUTE_IN_SECONDS );
  				}

  				else {
  					return new WP_Error( 'broke', __( "Could not connect to DarkSky API.", "simple-weather" ) );
  				}

          $return['forecast'] = $transient;

  			}

			}

      /** Get Weather from OpenWeater */
      else {

        if( empty( $atts['api'] ) ){
          $apis = array( '3b0095a1f393a1078abe2b5e1e05bcee', '88947377c35d3fd16142860b600409f5', '5e4c75d656c33b531db6811bcd3dadac' );
          $atts['api'] 	= $apis[array_rand( $apis, 1 )];
        }

        if( empty( $atts['api'] ) || ! $atts['api'] ) return new WP_Error( 'no_api', esc_html__('OpenWeather need an API key.', 'simple-weather'), array( 'status' => 401 ) );

        $openweather_route = 'http://api.openweathermap.org/data/2.5/';

        $query_args = array(
          'units' => $atts['units'],
          'lang'  => $atts['lang'],
          'APPID' => $atts['api']
        );

				/** Check for auto location */
				if( $atts['location'] === 'auto' ){
          $location = self::get_location();

          if( is_array( $location ) ){
             $atts['latitude'] = $location[0];
             $atts['longitude'] = $location[1];
          } else if( strlen( $location ) > 0 ){
            $atts['location'] = $location;
          }
				}

				/* Get Open Weather by coordinates */
				if( isset( $atts['latitude'] ) && ! empty( $atts['latitude'] ) && isset( $atts['longitude'] ) && ! empty( $atts['longitude'] ) ){
          $query_args['lat'] = esc_attr( $atts['latitude'] );
          $query_args['lon'] = esc_attr( $atts['longitude'] );
				}

				/* Get Open Weather by location */
				else if( isset( $atts['location'] ) && ! empty( $atts['location'] ) ){
          $query_args['q'] = esc_attr( $atts['location'] );
				}

				/* Cannot get weather without location or coordinates */
				else {
					return new WP_Error( 'could_not_get_location', esc_html__('OpenWeather needs a location or latitude & longitude coordinates, in order to show the weather.', 'sd'), array( 'status' => 404 ) );
				}

        if( isset( $atts['show_current'] ) && wp_validate_boolean( $atts['show_current'] ) ){

          $result = wp_remote_get( esc_url_raw( add_query_arg( $query_args, $openweather_route . 'weather' ) ), array( 'timeout' => intval( $atts['timeout'] ) ) );

          if ( ! is_wp_error( $result ) ) {
            $return['current'] = json_decode( wp_remote_retrieve_body( $result ) );
          }

        }

        $query_args['cnt'] = 16;

        $hash = md5( implode( '', $query_args ) );

        $transient = get_transient( 'sw_data_' . $hash );

        if( ! $transient ){

          $result = wp_remote_get( esc_url_raw( add_query_arg( $query_args, $openweather_route . 'forecast/daily' ) ), array( 'timeout' => intval( $atts['timeout'] ) ) );

          if ( ! is_wp_error( $result ) ) {

            $transient = json_decode( wp_remote_retrieve_body( $result ) );

            if( intval( $atts['freq'] ) > 0 ) set_transient( "sw_data_$hash", $transient, intval( $atts['freq'] ) * MINUTE_IN_SECONDS );

          } else {
            return new WP_Error( 'could_not_get_weather', esc_html__('OpenWeather could not provide weather.', 'sd'), array( 'status' => 404 ) );
          }

        }

        $return['forecast'] = $transient;

			}

			return $return;

		}

		function footer(){
			wp_localize_script( 'simple-weather-main', 'SimpleWeatherAtts', wp_cache_get( 'atts', 'SimpleWeather' ) );
      wp_localize_script( 'simple-weather-main', 'SimpleWeatherFeeds', wp_cache_get( 'feeds', 'SimpleWeather' ) );
		}

		/** Load Scripts */
		function load_scripts() {
			if ( ! is_admin() ) {
				wp_enqueue_style( 'simple-weather', plugins_url( '/css/simple-weather.css' , __FILE__ ), null, is_user_logged_in() ? rand() : '3.0'  );

				wp_enqueue_script(
          'simple-weather-vue',
          is_user_logged_in() ? plugins_url( '/js/vue.js' , __FILE__ ) : plugins_url( '/js/vue.min.js' , __FILE__ ),
          array( 'jquery' ),
          null,
          true
        );
				wp_enqueue_script(
          'simple-weather-vue-resource',
          is_user_logged_in() ? plugins_url( '/js/vue-resource.js' , __FILE__ ) : plugins_url( '/js/vue-resource.min.js' , __FILE__ ),
          array( 'simple-weather-vue' ),
          null,
          true
        );
				wp_enqueue_script(
          'simple-weather-moment',
          is_user_logged_in() ? plugins_url( '/js/moment.js' , __FILE__ ) : plugins_url( '/js/moment.min.js' , __FILE__ ),
          array( 'simple-weather-vue' ),
          null,
          true
        );

				wp_enqueue_script( 'simple-weather-main', plugins_url( '/js/simple-weather.js' , __FILE__ ), array( 'jquery', 'simple-weather-vue', 'simple-weather-vue-resource', 'simple-weather-moment' ), rand(), true );

        $options = get_option( 'simple-weather-options', apply_filters( 'simple-weather-options', array() ) );

        global $wp_locale;

        wp_localize_script( 'simple-weather-main', 'SimpleWeather', array(
          'rest_route' => get_rest_url(),
          'locale' => array(
      			'firstDay' => intval( get_option( 'start_of_week') ),
      			'months' => array_values( $wp_locale->month ),
      			'monthsShort' => array_values( $wp_locale->month_abbrev ),
      			'weekdays' => array_values( $wp_locale->weekday ),
      			'weekdaysShort' => array_values( $wp_locale->weekday_abbrev ),
      			'weekdaysMin' => array_values( $wp_locale->weekday_initial )
      		)
        ));

			}
		}

    public static function get_location(){

      $ip = $_SERVER['REMOTE_ADDR'];
      $ip_transient = 'sw_ip_' . md5( $ip );

      $location_data = get_transient( $ip_transient );

      if( ! $location_data ){
        $ip_file = wp_remote_get( 'http://freegeoip.net/json/' . $ip );
        if( ! is_wp_error( $ip_file ) ){
          $ip_data = json_decode( $ip_file['body'], true );
          $location_data = $ip_data['city'].', '.$ip_data['country_code'];
          set_transient( $ip_transient, $location_data, 6 * MONTH_IN_SECONDS );
        }
      }

      if( ! $location_data ){
        $ip_file = wp_remote_get( 'http://geoip.nekudo.com/api/' . $ip );
        if( ! is_wp_error( $ip_file ) ){
          $ip_data = json_decode( $ip_file['body'], true );
          $location_data = ! empty( $ip_data['city'] ) && ! $ip_data['city'] ? $ip_data['city'].', '.$ip_data['country']['code'] : array( 'lat' => $ip_data['location']['latitude'], 'long' => $ip_data['location']['longitude'] );
          set_transient( $ip_transient, $location_data, 6 * MONTH_IN_SECONDS );
        }
      }

      if( ! $location_data ){
        $ip_file = wp_remote_get( 'http://www.geoplugin.net/json.gp?ip=' . $ip );
        if( ! is_wp_error( $ip_file ) ){
          $ip_data = json_decode( $ip_file['body'], true );
          $location_data = ! empty( $ip_data['geoplugin_city'] ) && ! $ip_data['geoplugin_city'] ? $ip_data['geoplugin_city'].', '.$ip_data['geoplugin_countryCode'] : array( 'lat' => $ip_data['geoplugin_latitude'], 'long' => $ip_data['geoplugin_longitude'] );
          set_transient( $ip_transient, $location_data, 6 * MONTH_IN_SECONDS );
        }

      }

      if( ! empty( $location_data ) && is_array( $location_data ) ){
        return array( $location_data['lat'], $location_data['long'] );
      }
      elseif( ! empty( $location_data ) && ! is_array( $location_data ) ) {
        return $location_data;
      }

      return;

    }

		/** Textdomain */
		function set_textdomain() {
			load_plugin_textdomain( 'SIMPLEWEATHER', false, dirname( plugin_basename( __FILE__ ) ). '/languages/' );
		}

		/** Weather Shortcode */
		function weather_shortcode( $atts ) {

      $options = get_option( 'simple-weather-options', apply_filters( 'simple-weather-options', array() ) );

			$atts = shortcode_atts( array(
				'latitude' => null,
				'longitude' => null,
				'location' => 'London, uk',
				'days' => 1,
				'units' => isset( $options['units'] ) ? esc_attr( $options['units'] ) : 'imperial',
				'show_units' => 'yes',
				'show_date'	=> 'yes',
				'night' => 'no',
				'date'	=> 'dddd',
				'api'	=> null,
				'interval' => null,
				'timeout' => null,
				'station' => isset( $options['station'] ) && ! empty( $options['station'] ) ? esc_attr( $options['station'] ) : 'openweather',
				'show_current' => 'yes',
				'text_align'	=> null,
				'display'	=> null,
				'style'		=> null,
        'title' => null,
        'inline_css' => null
			), $atts, 'simple-weather' );

			$template = simple_weather_get_template_part( 'app' );
			$id = md5( htmlspecialchars( json_encode( $atts ), ENT_QUOTES, 'UTF-8') );

      /* Set atts to footer */
      $cache = wp_cache_get( 'atts', 'SimpleWeather' );
			if( ! $cache ){
				$cache = array( $id => $atts );
				wp_cache_set( 'atts', $cache, 'SimpleWeather' );
			} else {
				if( ! isset( $cache[$id] ) ){
					$cache[$id] = $atts;
					wp_cache_set( 'atts', $cache, 'SimpleWeather' );
				}
			}

      /* Preload weather if async is off */
      if( ! wp_validate_boolean( $options['async'] ) ){
        $cache_feed = wp_cache_get( 'feeds', 'SimpleWeather' );
        if( ! $cache_feed ){
          $cache_feed = array( $id => self::get_weather_file_new( $atts ) );
          wp_cache_set( 'feeds', $cache_feed, 'SimpleWeather' );
        } else {
          if( ! isset( $cache_feed[$id] ) ){
            $cache_feed[$id] = self::get_weather_file_new( $atts );
            wp_cache_set( 'feeds', $cache_feed, 'SimpleWeather' );
          }
        }
      }

      ob_start();

			if( isset( $template ) && ! empty( $template ) && $template !== false ) include( $template );

			return ob_get_clean();

		}

	}

	new CurlySimpleWeather();
}
?>
